@@ -107,9 +107,9 @@ insert_keywords (TrackerSparqlBuilder *metadata,
 		keywords[len - 1] = '\0';
 	}
 
-	for (keyw = strtok_r (keywords, ",;", &lasts); 
+	for (keyw = strtok_r (keywords, ",; ", &lasts); 
 	     keyw;
-	     keyw = strtok_r (NULL, ",;", &lasts)) {
+	     keyw = strtok_r (NULL, ",; ", &lasts)) {
 		tracker_sparql_builder_predicate (metadata, "nao:hasTag");
 
 		tracker_sparql_builder_object_blank_open (metadata);
@@ -156,10 +156,10 @@ read_metadata (TrackerSparqlBuilder *preupdate,
 			 * theoretically possible that the function gets
 			 * called multiple times 
 			 */
-			tracker_xmp_read (text_ptr[i].text,
-			                  text_ptr[i].itxt_length,
-			                  uri, 
-			                  &xd);
+			tracker_extract_xmp_read (text_ptr[i].text,
+			                          text_ptr[i].itxt_length,
+			                          uri, 
+			                          &xd);
 
 			continue;
 		}
@@ -171,10 +171,10 @@ read_metadata (TrackerSparqlBuilder *preupdate,
 		 * http://www.sno.phy.queensu.ca/~phil/exiftool/TagNames/PNG.html#TextualData 
 		 */
 		if (g_strcmp0 ("Raw profile type exif", text_ptr[i].key) == 0) {
-			tracker_exif_read (text_ptr[i].text,
-			                   text_ptr[i].itxt_length, 
-			                   uri, 
-			                   &ed);
+			tracker_extract_exif_read (text_ptr[i].text,
+			                           text_ptr[i].itxt_length, 
+			                           uri, 
+			                           &ed);
 			continue;
 		}
 #endif /* HAVE_LIBEXIF */
